@@ -54,6 +54,12 @@ private slots:
 
     void on_actionReadme_triggered();
 
+    void initialshow();
+
+    void initialseen();
+
+    void initialpsb();
+
 private:
     Ui::MainWindow *ui;
     About *about;
