@@ -63,7 +63,7 @@ $r $d $t \
 }
 
 #Text Strings
-sucess="Swap Refresh Sucessful"
+sucess="Swap Refresh Successful"
 safe="Safe to Remove Back Cover"
 failed="Operation Failed"
 bcwarn="DO NOT REMOVE BACK COVER - Please check swaps"
